get_votings_table: Importing votings table from a database
Description
Function get_votings_table imports votings table from a database.Usage
get_votings_table(dbname = 'sejmrp', user = 'reader',
password = 'qux94874', host = 'services.mini.pw.edu.pl',
sorted_by_id = TRUE, windows = .Platform$OS.type == 'windows')
Arguments
dbname
name of database; default: 'sejmrp'
user
name of user; default: 'reader'
password
password of database; default: 'qux94874'
host
name of host; default: 'services.mini.pw.edu.pl'
sorted_by_id
information if table should be sorted by id; default: TRUE
windows
information of used operation system;
default: .Platform$OS.type == 'windows'
Details
Function get_votings_table imports votings table from a database.
The result of this function is a data frame with votings' data. Because of
encoding issue on Windows operation system, you need to select if you use Windows.Examples
Run this codevotings <- get_votings_table()
dim(votings)
# [1] 6212 6
names(votings)
# [1] 'id_voting' 'nr_meeting' 'date_meeting'
# [4] 'nr_voting' 'topic_voting' 'link_results'
Run the code above in your browser using DataLab